#!/usr/bin/env python
# -*- coding: utf-8 -*-

__author__ = 'Thomas Sterren'
__contributors__ = ['Martin Meyer', ]
__version__ = '1.0.3'


def main():
    print(__version__)


if __name__ == '__main__':
    main()
